@@ -225,7 +225,7 @@ def check_3dlut_format(devicename):
 					getcfg("3dlut.bitdepth.output") == 12)
 
 
-def getbitmap(name, display_missing_icon=True, scale=True):
+def getbitmap(name, display_missing_icon=True, scale=True, use_mask=False):
 	"""
 	Create (if necessary) and return a named bitmap.
 	
@@ -262,17 +262,24 @@ def getbitmap(name, display_missing_icon=True, scale=True):
 			w = int(round(w * scale))
 			h = int(round(h * scale))
 		if parts[-1] == "empty":
-			bitmaps[name] = wx.EmptyBitmap(w, h, depth=-1)
-			dc = wx.MemoryDC()
-			dc.SelectObject(bitmaps[name])
-			dc.SetBackground(wx.Brush("black"))
-			dc.Clear()
-			dc.SelectObject(wx.NullBitmap)
-			bitmaps[name].SetMaskColour("black")
+			if use_mask and sys.platform == "win32":
+				bmp = wx.EmptyBitmap(w, h)
+				bmp.SetMaskColour(wx.Colour(0, 0, 0))
+			else:
+				bmp = wx.EmptyBitmapRGBA(w, h, 255, 0, 255, 0)
 		else:
 			if parts[-1].startswith(appname):
 				parts[-1] = parts[-1].lower()
 			oname = parts[-1]
+			if "#" in oname:
+				# Hex format, RRGGBB or RRGGBBAA
+				oname, color = oname.split("#", 1)
+				parts[-1] = oname
+			else:
+				color = None
+			inverted = oname.endswith("-inverted")
+			if inverted:
+				oname = parts[-1] = oname.split("-inverted")[0]
 			name2x = oname + "@2x"
 			name4x = oname + "@4x"
 			path = None
@@ -316,7 +323,7 @@ def getbitmap(name, display_missing_icon=True, scale=True):
 							# Try original size
 							parts[-1] = oname
 				if (sys.platform not in ("darwin", "win32") and
-					parts[-1].startswith(appname)):
+					parts[-1].startswith(appname.lower())):
 					# Search /usr/share/icons on Linux first
 					path = get_data_path(os.path.join(parts[-2], "apps", parts[-1]) + ".png")
 				if not path:
@@ -324,26 +331,30 @@ def getbitmap(name, display_missing_icon=True, scale=True):
 				if path or scale == 1:
 					break
 			if path:
-				bitmaps[name] = wx.Bitmap(path)
-				if not bitmaps[name].IsOk():
+				bmp = wx.Bitmap(path)
+				if not bmp.IsOk():
 					path = None
 			if path:
+				img = None
 				if scale > 1 and i:
 					rescale = False
 					if i in (1, 2):
 						# HighDPI support. 4x/2x version, determine scaled size
-						w, h = [int(round(v / (2 * (3 - i)) * scale)) for v in bitmaps[name].Size]
+						w, h = [int(round(v / (2 * (3 - i)) * scale)) for v in bmp.Size]
 						rescale = True
 					elif len(size) == 2:
 						# HighDPI support. Icon
 						rescale = True
-					if rescale and (bitmaps[name].Size[0] != w or
-									bitmaps[name].Size[1] != h):
+					if rescale and (bmp.Size[0] != w or
+									bmp.Size[1] != h):
 						# HighDPI support. Rescale
-						img = bitmaps[name].ConvertToImage()
-						if not hasattr(wx, "IMAGE_QUALITY_BILINEAR"):
+						img = bmp.ConvertToImage()
+						if (not hasattr(wx, "IMAGE_QUALITY_BILINEAR") or
+							oname == "list-add"):
+							# In case bilinear is not supported, and to prevent
+							# black borders after resizing for some images
 							quality = wx.IMAGE_QUALITY_NORMAL
-						elif oname == "rgbsquares":
+						elif oname in ():
 							# Hmm. Everything else looks great with bicubic,
 							# but this one gets jaggy unless we use bilinear
 							quality = wx.IMAGE_QUALITY_BILINEAR
@@ -352,20 +363,71 @@ def getbitmap(name, display_missing_icon=True, scale=True):
 						else:
 							quality = wx.IMAGE_QUALITY_BILINEAR
 						img.Rescale(w, h, quality=quality)
-						bitmaps[name] = img.ConvertToBitmap()
-			else:
+				factors = None
+				if (not inverted and len(parts) > 2 and parts[-3] == "icons" and
+					max(wx.SystemSettings.GetColour(wx.SYS_COLOUR_WINDOW)[:3]) < 102):
+					if not img:
+						img = bmp.ConvertToImage()
+					if img.IsBW():
+						inverted = True
+				# Invert after resize (avoids jaggies)
+				if inverted:
+					if not img:
+						img = bmp.ConvertToImage()
+					img.Invert()
+					alpha = wx.SystemSettings.GetColour(wx.SYS_COLOUR_BTNTEXT).alpha
+					if oname in ["applications-system", "color",
+								 "document-open", "document-save-as",
+								 "edit-delete", "image-x-generic", "info",
+								 "install", "list-add", "package-x-generic",
+								 "question", "rgbsquares",
+								 "stock_3d-color-picker", "stock_lock",
+								 "stock_lock-open", "stock_refresh", "web",
+								 "window-center", "zoom-best-fit", "zoom-in",
+								 "zoom-original", "zoom-out"]:
+						# Scale 85 to 255 and adjust alpha
+						factors = (3, 3, 3, alpha / 255.0)
+					else:
+						# Only adjust alpha
+						factors = (1, 1, 1, alpha / 255.0)
+				if color or factors:
+					if not img:
+						img = bmp.ConvertToImage()
+					if color:
+						# Hex format, RRGGBB or RRGGBBAA
+						R = int(color[0:2], 16) / 255.0
+						G = int(color[2:4], 16) / 255.0
+						B = int(color[4:6], 16) / 255.0
+						if len(color) > 6:
+							alpha = int(color[6:8], 16) / 255.0
+						else:
+							alpha = 1.0
+					else:
+						R, G, B = factors[:3]
+						if len(factors) > 3:
+							alpha = factors[3]
+						else:
+							alpha = 1.0
+					img = img.AdjustChannels(R, G, B, alpha)
+				if img:
+					bmp = img.ConvertToBitmap()
+					if not bmp.IsOk():
+						path = None
+			if not path:
+				from log import safe_print
+				safe_print("Warning: Missing bitmap '%s'" % name)
 				img = wx.EmptyImage(w, h)
 				img.SetMaskColour(0, 0, 0)
 				img.InitAlpha()
 				bmp = img.ConvertToBitmap()
-				bitmaps[name] = bmp
 				dc = wx.MemoryDC()
-				dc.SelectObject(bitmaps[name])
+				dc.SelectObject(bmp)
 				if display_missing_icon:
-					bmp = wx.ArtProvider.GetBitmap(wx.ART_MISSING_IMAGE,
+					art = wx.ArtProvider.GetBitmap(wx.ART_MISSING_IMAGE,
 												   size=(w, h))
-					dc.DrawBitmap(bmp, 0, 0, True)
+					dc.DrawBitmap(art, 0, 0, True)
 				dc.SelectObject(wx.NullBitmap)
+		bitmaps[name] = bmp
 	return bitmaps[name]
 
 
@@ -506,10 +568,11 @@ def get_measureframe_dimensions(dimensions_measureframe=None, percent=10):
 	return ",".join([str(min(n, 50)) for n in dimensions_measureframe])
 
 
-def geticon(size, name, scale=True):
+def geticon(size, name, scale=True, use_mask=False):
 	""" Convenience function for getbitmap('theme/icons/<size>/<name>'). """
 	return getbitmap("theme/icons/%(size)sx%(size)s/%(name)s" % 
-					 {"size": size, "name": name}, scale=scale)
+					 {"size": size, "name": name}, scale=scale,
+					 use_mask=use_mask)
 
 
 def get_data_path(relpath, rex=None):
@@ -662,6 +725,7 @@ valid_ranges = {
 	"measure.min_display_update_delay_ms": [20, 60000],
 	"multiprocessing.max_cpus": [0, 65],
 	"patterngenerator.apl": [0.0, 1.0],
+	"patterngenerator.quantize_bits": [0, 32],
 	"patterngenerator.resolve.port": [1, 65535],
 	"profile_loader.quantize_bits": [8, 16],
 	"synthprofile.trc_gamma": [0.01, 10],
@@ -725,6 +789,7 @@ valid_values = {
 	"profile.quality.b2a": ["l", "m", "h", "u", "n", None],
 	"profile.b2a.hires.size": [-1, 9, 17, 33, 45, 65],
 	"profile.type": ["g", "G", "l", "s", "S", "x", "X"],
+	"profile_loader.tray_icon_animation_quality": [0, 1, 2],
 	"synthprofile.black_point_compensation": [0, 1],
 	"synthprofile.trc_gamma_type": ["g", "G"],
 	"tc_algo": ["", "t", "r", "R", "q", "Q", "i", "I"],  # Q = Argyll >= 1.1.0
@@ -926,6 +991,7 @@ defaults = {
 	"patterngenerator.prisma.host": "",
 	"patterngenerator.prisma.preset": "Custom-1",
 	"patterngenerator.prisma.port": 80,
+	"patterngenerator.quantize_bits": 0,
 	"patterngenerator.resolve": "CM",
 	"patterngenerator.resolve.port": 20002,
 	"patterngenerator.use_video_levels": 0,
@@ -949,7 +1015,9 @@ defaults = {
 	"position.synthiccframe.y": 50,
 	"position.tcgen.x": 50,
 	"position.tcgen.y": 50,
-	"profile.black_point_compensation": 0,
+	# Force black point compensation due to OS X
+	# bugs with non BPC profiles
+	"profile.black_point_compensation": 0 if sys.platform != "darwin" else 1,
 	"profile.black_point_correction": 0.0,
 	"profile.create_gamut_views": 1,
 	"profile.install_scope": "l" if (sys.platform != "win32" and 
@@ -979,13 +1047,17 @@ defaults = {
 	"profile.b2a.hires.size": -1,
 	"profile.b2a.hires.smooth": 1,
 	"profile.save_path": storage, # directory
-	"profile.type": "X",
+	# Force profile type to single shaper + matrix
+	# due to OS X bugs with cLUT profiles and
+	# matrix profiles with individual shaper curves
+	"profile.type": "X" if sys.platform != "darwin" else "S",
 	"profile.update": 0,
 	"profile_loader.buggy_video_drivers":  ";".join(["*"]),
 	"profile_loader.check_gamma_ramps": 1,
 	"profile_loader.error.show_msg": 1,
 	"profile_loader.exceptions": "",
 	"profile_loader.fix_profile_associations": 1,
+	"profile_loader.ignore_unchanged_gamma_ramps": 1,
 	"profile_loader.known_apps": ";".join(["basiccolor display.exe",
 										   "calclient.exe",
 										   "coloreyes display pro.exe",
@@ -1018,6 +1090,7 @@ defaults = {
 	"profile_loader.reset_gamma_ramps": 0,
 	"profile_loader.show_notifications": 0,
 	"profile_loader.track_other_processes": 1,
+	"profile_loader.tray_icon_animation_quality": 2,
 	"profile_loader.use_madhcnet": 0,
 	"profile_loader.verify_calibration": 0,
 	"recent_cals": "",
@@ -1086,7 +1159,10 @@ defaults = {
 	"tc_vrml_use_D50": 0,
 	"tc_white_patches": 4,
 	"tc.show": 0,
-	"testchart.auto_optimize": 4,
+	# Profile type forced to matrix due to
+	# OS X bugs with cLUT profiles. Set
+	# smallest testchart.
+	"testchart.auto_optimize": 4 if sys.platform != "darwin" else 1,
 	"testchart.file": "auto",
 	"testchart.file.backup": "auto",
 	"testchart.patch_sequence": "optimize_display_response_delay",
@@ -1717,8 +1793,9 @@ def writecfg(which="user", worker=None, module=None, options=()):
 _init_testcharts()
 runtype = runtimeconfig(pyfile)
 
-if isapp and not os.getenv("SSL_CERT_FILE"):
+if sys.platform in ("darwin", "win32") and not os.getenv("SSL_CERT_FILE"):
 	# Use our bundled CA file
+	# https://github.com/certifi/python-certifi/blob/master/certifi/cacert.pem
 	cafile = get_data_path("cacert.pem")
 	if cafile:
 		os.environ["SSL_CERT_FILE"] = cafile.encode(fs_enc, "replace")
